@@ -63,7 +63,6 @@ def hares_upload(siteinfo,file1,record_path,qbinfo,basic,hashlist):
     else:
         medium_sel='5'
     logger.info('已成功填写来源为'+file1.type)
-   
 
 
     #选择编码
@@ -208,6 +207,9 @@ def hares_upload(siteinfo,file1,record_path,qbinfo,basic,hashlist):
     if '国' in file1.language or '中' in file1.language:
         tags.append(6)
         logger.info('已选择国语')
+    if '粤' in file1.language:
+        tags.append(7)
+        logger.info('已选择粤语')
     if not file1.sublan=='' and ('简' in file1.sublan or '繁' in file1.sublan or '中' in file1.sublan):
         tags.append(9)
         logger.info('已选择中字')
